package com.yeejoin.equipmanage.service.impl;

import com.google.common.collect.Maps;
import com.yeejoin.equipmanage.common.utils.DateUtils;
import com.yeejoin.equipmanage.mapper.CarMapper;
import com.yeejoin.equipmanage.mapper.EquipmentSpecificAlarmLogMapper;
import com.yeejoin.equipmanage.mapper.EquipmentSpecificMapper;
import com.yeejoin.equipmanage.service.IEquipmentInfoOnPlanService;
import org.apache.commons.compress.utils.Lists;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.typroject.tyboot.core.foundation.utils.ValidationUtil;

import java.text.SimpleDateFormat;
import java.util.*;

/**
 * @author keyong
 * @title: EquipmentInfoOnPlanServiceImpl
 * <pre>
 * @description: TODO
 * </pre>
 * @date 2022/5/12 11:43
 */
@Service("EquipmentInfoOnPlanService")
public class EquipmentInfoOnPlanServiceImpl implements IEquipmentInfoOnPlanService {

    @Autowired
    private EquipmentSpecificMapper equipmentSpecificMapper;

    @Autowired
    private EquipmentSpecificAlarmLogMapper equipmentSpecificAlarmLogMapper;

    @Autowired
    private CarMapper carMapper;

    @Value("${equipment.plan.monitor}")
    String monitorCodes;

    @Value("${equipment.plan.pump}")
    String pumpCodes;

    @Override
    public List<Map<String, Object>> getFireMonitorInfo(Long fireEquipmentId) {
        String[] strings = monitorCodes.split(",");
        List<Map<String, Object>> list = equipmentSpecificMapper.getFireMonitorInfo(fireEquipmentId, strings);
        return Optional.ofNullable(list).orElse(Lists.newArrayList());
    }

    @Override
    public List<Map<String, Object>> getFirePumpInfo() {
        String[] strings = pumpCodes.split(",");
        List<Map<String, Object>> list = equipmentSpecificMapper.getFirePumpInfo(strings);
        return Optional.ofNullable(list).orElse(Lists.newArrayList());
    }

    @Override
    public List<Map<String, Object>> getOtherEquipInfo() {
        Map<String, Object> map = equipmentSpecificAlarmLogMapper.getPlanRecord();
        Date startTime = null;
        Long equipmentId = null;
        if (!ValidationUtil.isEmpty(map)) {
            try {
                startTime = DateUtils.dateParse(String.valueOf(map.get("startTime")), DateUtils.DATE_TIME_T_PATTERN);
                equipmentId = Long.valueOf(String.valueOf(map.get("equipmentId")));
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
        String dateParam = startTime == null ? null : new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(startTime);
        List<Map<String, Object>> list = equipmentSpecificAlarmLogMapper.getOtherEquipInfo(dateParam, equipmentId);
        return Optional.ofNullable(list).orElse(Lists.newArrayList());
    }

    @Override
    public Map<String, Object> getFirePowerAndCarInfo() {
        List<Map<String, Object>> firePowerMap = carMapper.getFirePowerInfo();
        List<Map<String, Object>> carStateMap = carMapper.getCarState();
        Map<String, Object> map = new HashMap<>();
        map.put("firePower", Optional.ofNullable(firePowerMap).orElse(Lists.newArrayList()));
        map.put("carState", Optional.ofNullable(carStateMap).orElse(Lists.newArrayList()));
        return map;
    }
}
